/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.ear.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.ow2.util.ee.deploy.api.deployable.EARDeployable;
import org.ow2.util.ee.deploy.api.deployable.EJB3Deployable;
import org.ow2.util.ee.metadata.car.api.ICarDeployableMetadata;
import org.ow2.util.ee.metadata.ear.api.IEarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;

/**
 * Implementation of ear deployable metadata.
 * @author Gael Lalire
 */
public class EarDeployableMetadata implements IEarDeployableMetadata {

    /**
     * List of car deployable.
     */
    private List<ICarDeployableMetadata> carDeployableMetadataList;

    /**
     * List of war deployable.
     */
    private List<IWarDeployableMetadata> warDeployableMetadataList;

    /**
     * List of ejb3 deployable.
     */
    private List<IEjbJarDeployableMetadata<EJB3Deployable, ?, ?, ?, ?>> ejbJarDeployableMetadataList;

    /**
     * The ear deployable.
     */
    private EARDeployable earDeployable;

    /**
     * Constructor.
     * @param earDeployable the ear deployable
     */
    public EarDeployableMetadata(final EARDeployable earDeployable) {
        this.earDeployable = earDeployable;
        carDeployableMetadataList = new ArrayList<ICarDeployableMetadata>();
        warDeployableMetadataList = new ArrayList<IWarDeployableMetadata>();
        ejbJarDeployableMetadataList = new ArrayList<IEjbJarDeployableMetadata<EJB3Deployable, ?, ?, ?, ?>>();
    }

    /**
     * Add a car deployable metadata.
     * @param carDeployableMetadata the car deployable metadata to add
     */
    public void addCarDeployableMetadata(final ICarDeployableMetadata carDeployableMetadata) {
        carDeployableMetadataList.add(carDeployableMetadata);
    }

    /**
     * Add a war deployable metadata.
     * @param warDeployableMetadata the war deployable metadata to add
     */
    public void addWarDeployableMetadata(final IWarDeployableMetadata warDeployableMetadata) {
        warDeployableMetadataList.add(warDeployableMetadata);
    }

    /**
     * Add a war deployable metadata.
     * @param ejbJarDeployableMetadata the ejb3 deployable metadata to add
     */
    public void addEjbJarDeployableMetadata(
            final IEjbJarDeployableMetadata<EJB3Deployable, ?, ?, ?, ?> ejbJarDeployableMetadata) {
        ejbJarDeployableMetadataList.add(ejbJarDeployableMetadata);
    }

    /**
     * @return a collection of client archive metadata.
     */
    public Collection<ICarDeployableMetadata> getCarDeployableMetadataCollection() {
        return carDeployableMetadataList;
    }

    /**
     * @return a collection of web archive metadata.
     */
    public Collection<IWarDeployableMetadata> getWarDeployableMetadataCollection() {
        return warDeployableMetadataList;
    }

    /**
     * @return a collection of ejb3 archive metadata.
     */
    public Collection<IEjbJarDeployableMetadata<EJB3Deployable, ?, ?, ?, ?>> getEjbJarDeployableMetadataCollection() {
        return ejbJarDeployableMetadataList;
    }

    /**
     * @return the ear deployable
     */
    public EARDeployable getDeployable() {
        return earDeployable;
    }


}
